# DbUploadFirmwareState

Upload firmware state

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**device_id** | **str** |  | 
**device_serial** | **str** |  | 
**device_type** | **str** |  | 
**upload_state** | **str** | Current state of the firmware upload process. States: - IDLE: Ready for a new upload. - IN_PROGRESS: Upload is currently in progress. - COMPLETED: Upload finished successfully. - FAILED: Upload failed.  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


